@@ -325,16 +325,6 @@ class LoadMaster(HttpClient):
                 virt_serv.real_servers.append(rs)
             virtual_services.append(virt_serv)
         # replace subvs's with vs's that have RSs in them.
-        """
-        for vs in virtual_services:
-            vs.subvs_entries = []
-            print(vs.subvs_entries)
-            parent_vs_id = vs.mastervsid
-            if parent_vs_id != 0:
-                for parent_vs in virtual_services:
-                    if parent_vs.index == parent_vs_id:
-                        parent_vs.subvs_entries.append(vs)
-        """
         for vs in virtual_services:
             for subvs in vs.subvs_entries:
                 for top_level_vs in virtual_services:
@@ -867,7 +857,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.checkpostdata = service.get('CheckPostData', None)
         self.rsruleprecedence = service.get('RSRulePrecedence', None)
         self.rsruleprecedencepos = service.get('RSRulePrecedencePos', None)
-        self.enhancedhealthchecks = service.get('EnhancedHealthchecks', None)
+        self.enhancedhealthchecks = service.get('EnhancedHealthChecks', None)
         self.rsminimum = service.get('RsMinimum', None)
 
     def create_sub_virtual_service(self):
