@@ -92,3 +92,27 @@ def get_dict_entry_as_list(key, data):
     if not isinstance(value, list):
         value = [value]
     return value
+
+
+def cast_to_list(data):
+    """Cast data to a list if it is not already a list.
+
+    :param data: The variable to be cast to a list.
+    :return: The data in a list
+    """
+    if not isinstance(data, list):
+        data = [data]
+    return data
+
+
+def falsey_to_none(var):
+    """Certain parameters return invalid 0 when they should be False
+
+    This function takes a variable, checks if its 'falsey' and return it
+    with the value of None if it is.
+    :param var: The variable to check
+    :return: The variable that was given, with value of None if it was falsey
+    """
+    if not var:
+        var = None
+    return var
